@@ -10,8 +10,9 @@ const translationMap = {
                 en: 'Script Location',
                 zh: '脚本位置',
                 zh_tw: '腳本位置',
+                ua: 'Місцезнаходження скрипта',
                 ru: 'Расположение скрипта',
-                de: 'Script Pfad',
+                de: 'Scriptpfad',
                 pt_br: 'Localização do Script',
                 sp: 'Localización del Script',
                 sp_la: 'Ubicacion del archivo',
@@ -30,8 +31,9 @@ const translationMap = {
                 en: 'Language',
                 zh: '语言',
                 zh_tw: '語言',
+                ua: 'Мова',
                 ru: 'идиома',
-                de: 'Idiom',
+                de: 'Sprache',
                 pt_br: 'Idioma',
                 sp: 'Idioma',
                 sp_la: 'Idioma',
@@ -50,6 +52,7 @@ const translationMap = {
                 en: 'Onefile',
                 zh: '单文件',
                 zh_tw: '單檔案',
+                ua: 'Один файл',
                 ru: 'Один файл',
                 de: 'Eine Datei',
                 pt_br: 'Arquivo Único',
@@ -70,6 +73,7 @@ const translationMap = {
                 en: 'Console Window',
                 zh: '控制台窗口',
                 zh_tw: '控制台視窗',
+                ua: 'Консольний застосунок',
                 ru: 'Консольное приложение',
                 de: 'Konsolen Anwendung',
                 pt_br: 'Janela do Console',
@@ -90,6 +94,7 @@ const translationMap = {
                 en: 'Icon',
                 zh: '图标',
                 zh_tw: '圖示',
+                ua: 'Іконка',
                 ru: 'Иконка',
                 de: 'Icon',
                 pt_br: 'Ícone',
@@ -110,6 +115,7 @@ const translationMap = {
                 en: 'Additional Files',
                 zh: '附加文件',
                 zh_tw: '附加檔案',
+                ua: 'Додаткові файли',
                 ru: 'Дополнительные файлы',
                 de: 'Dateien hinzufügen',
                 pt_br: 'Arquivos Adicionais',
@@ -130,6 +136,7 @@ const translationMap = {
                 en: 'Advanced',
                 zh: '高级',
                 zh_tw: '進階',
+                ua: 'Додаткові',
                 ru: 'Расширенные',
                 de: 'Erweitert',
                 pt_br: 'Avançado',
@@ -150,6 +157,7 @@ const translationMap = {
                 en: 'Settings',
                 zh: '设置',
                 zh_tw: '設定',
+                ua: 'Налаштування',
                 ru: 'Настройки',
                 de: 'Einstellungen',
                 pt_br: 'Configurações',
@@ -170,6 +178,7 @@ const translationMap = {
                 en: 'Current Command',
                 zh: '当前命令',
                 zh_tw: '當前命令',
+                ua: 'Поточна команда',
                 ru: 'Текущая команда',
                 de: 'Aktueller Befehl',
                 pt_br: 'Comando Atual',
@@ -190,6 +199,7 @@ const translationMap = {
                 en: 'Output',
                 zh: '输出',
                 zh_tw: '輸出',
+                ua: 'Вивід',
                 ru: 'Вывод',
                 de: 'Ausgabe',
                 pt_br: 'Saída',
@@ -209,6 +219,7 @@ const translationMap = {
                 en: `${applicationName} Specific Options`,
                 zh: `${applicationName} 特定的选项`,
                 zh_tw: `${applicationName} 特定的選項`,
+                ua: `Особливі параметри ${applicationName}`,
                 ru: `Особые параметры ${applicationName}`,
                 de: `${applicationName} spezifische Optionen`,
                 pt_br: `Opções Específicas ${applicationName}`,
@@ -229,6 +240,7 @@ const translationMap = {
                 en: 'Output Directory',
                 zh: '输出路径',
                 zh_tw: '輸出路徑',
+                ua: 'Директорія Виводу',
                 ru: 'Папка Вывода',
                 de: 'Ausgabeverzeichnis',
                 pt_br: 'Diretório de Saída',
@@ -249,6 +261,7 @@ const translationMap = {
                 en: 'Increase Recursion Limit',
                 zh: '增加递归限制',
                 zh_tw: '增加遞歸限制',
+                ua: 'Збільшити Ліміт Глибини Рекурсії',
                 ru: 'Увеличить Лимит Рекурсии',
                 de: 'Erhöhen der Rekursionsbegrenzung',
                 pt_br: 'Limite de Recursividade',
@@ -269,6 +282,7 @@ const translationMap = {
                 en: 'Manually Provide Options',
                 zh: '手动提供选项',
                 zh_tw: '手動提供選項',
+                ua: 'Параметри Вказані Вручну',
                 ru: 'Вручную Указанные Параметры',
                 de: 'Optionen manuell eingeben',
                 pt_br: 'Opções Manuais',
@@ -289,6 +303,7 @@ const translationMap = {
                 en: 'Manual Argument Input',
                 zh: '手动参数输入',
                 zh_tw: '手動參數輸入',
+                ua: 'Додати аргументи вручну',
                 ru: 'Ручной Ввод Аргументов',
                 de: 'Manuelle Argumenteingabe',
                 pt_br: 'Argumentos de Entrada',
@@ -309,6 +324,7 @@ const translationMap = {
                 en: 'Configuration',
                 zh: '配置',
                 zh_tw: '配置',
+                ua: 'Конфігурація',
                 ru: 'Конфигурация',
                 de: 'Konfiguration',
                 pt_br: 'Configuração',
@@ -331,6 +347,7 @@ const translationMap = {
                 en: 'Browse',
                 zh: '浏览',
                 zh_tw: '瀏覽',
+                ua: 'Місцезнаходження',
                 ru: 'Расположение',
                 de: 'Durchsuchen',
                 pt_br: 'Exibir',
@@ -351,6 +368,7 @@ const translationMap = {
                 en: 'One Directory',
                 zh: '单目录',
                 zh_tw: '單目錄',
+                ua: 'Одна Директорія',
                 ru: 'Одна Папка',
                 de: 'Ein Verzeichnis',
                 pt_br: 'Um Diretório',
@@ -371,6 +389,7 @@ const translationMap = {
                 en: 'One File',
                 zh: '单文件',
                 zh_tw: '單檔案',
+                ua: 'Один файл',
                 ru: 'Один файл',
                 de: 'Eine Datei',
                 pt_br: 'Um Arquivo',
@@ -391,6 +410,7 @@ const translationMap = {
                 en: 'Console Based',
                 zh: '基于控制台的',
                 zh_tw: '基於控制台',
+                ua: 'Консольний Застосунок',
                 ru: 'Консольное Приложение',
                 de: 'Befehlszeilenbasiert',
                 pt_br: 'Baseado em Console',
@@ -411,6 +431,7 @@ const translationMap = {
                 en: 'Window Based (hide the console)',
                 zh: '基于窗口的 (隐藏控制台)',
                 zh_tw: '基於視窗 (隱藏控制台)',
+                ua: 'Віконний Застосунок (приховати консоль)',
                 ru: 'Оконное Приложение (скрыть консоль)',
                 de: 'Fensterbasiert (Befehlszeile ausblenden)',
                 pt_br: 'Baseado em Janela (ocultar o console)',
@@ -431,6 +452,7 @@ const translationMap = {
                 en: 'Add Files',
                 zh: '添加文件',
                 zh_tw: '新增檔案',
+                ua: 'Додати Файли',
                 ru: 'Добавить Файлы',
                 de: 'Dateien hinzufügen',
                 pt_br: 'Adicionar Arquivos',
@@ -451,6 +473,7 @@ const translationMap = {
                 en: 'Add Folder',
                 zh: '添加目录',
                 zh_tw: '新增目錄',
+                ua: 'Додати директорію',
                 ru: 'Добавить Папку',
                 de: 'Verzeichnis hinzufügen',
                 pt_br: 'Adicionar Pasta',
@@ -471,6 +494,7 @@ const translationMap = {
                 en: 'Add Blank',
                 zh: '添加空白',
                 zh_tw: '新增空白',
+                ua: 'Додати шаблон',
                 ru: 'Добавить шаблон',
                 de: 'Leerzeichen hinzufügen',
                 pt_br: 'Adicionar em Branco',
@@ -491,6 +515,7 @@ const translationMap = {
                 en: 'Import Config From JSON File',
                 zh: '从JSON文件导入配置',
                 zh_tw: '從 JSON 檔案導入配置',
+                ua: 'Імпортувати Конфігурацію з файлу JSON',
                 ru: 'Импортировать Конфигурацию из JSON Файла',
                 de: 'Konfiguration aus JSON-Datei importieren',
                 pt_br: 'Importar Config de Arquivo JSON',
@@ -511,6 +536,7 @@ const translationMap = {
                 en: 'Export Config To JSON File',
                 zh: '将配置导出到JSON文件',
                 zh_tw: '將配置導出到 JSON 檔案',
+                ua: 'Експортувати Конфігурацію у файл JSON',
                 ru: 'Экспортировать Конфигурацию в JSON Файл',
                 de: 'Konfiguration in JSON-Datei exportieren',
                 pt_br: 'Exportar Config para Arquivo JSON',
@@ -530,6 +556,7 @@ const translationMap = {
                 en: 'Convert .py to .exe',
                 zh: '将.PY转换为.EXE',
                 zh_tw: '將.PY 轉換為 .EXE',
+                ua: 'Конвертувати .py в .exe',
                 ru: 'Конвертировать .py В .exe',
                 de: 'Konvertiere .py in .exe',
                 pt_br: 'Converter .py para .exe',
@@ -550,6 +577,7 @@ const translationMap = {
                 en: 'Open Output Folder',
                 zh: '打开输出目录',
                 zh_tw: '打開輸出目錄',
+                ua: 'Відкрити Кінцеву Директорію',
                 ru: 'Открыть Папку Вывода',
                 de: 'Ausgabeverzeichnis öffnen',
                 pt_br: 'Abrir Pasta de Saída',
@@ -570,6 +598,7 @@ const translationMap = {
                 en: 'Enable',
                 zh: '开启',
                 zh_tw: '開啟',
+                ua: 'Увімкнути',
                 ru: 'Включить',
                 de: 'Aktivieren',
                 pt_br: 'Habilitar',
@@ -592,6 +621,7 @@ const translationMap = {
                 en: 'Help Post',
                 zh: '帮助帖子',
                 zh_tw: '幫助文章',
+                ua: 'Довідка',
                 ru: 'Справка',
                 de: 'Hilfe-Post',
                 pt_br: 'Post Ajuda',
@@ -614,6 +644,7 @@ const translationMap = {
                 en: 'Path to file',
                 zh: '文件路径',
                 zh_tw: '檔案路徑',
+                ua: 'Шлях до файлу',
                 ru: 'Путь к файлу',
                 de: 'Pfad zur Datei',
                 pt_br: 'Caminhao para Arquivo',
@@ -634,6 +665,7 @@ const translationMap = {
                 en: '.ico file',
                 zh: '图标路径',
                 zh_tw: '圖示路徑',
+                ua: '.ico файл',
                 ru: '.ico файл',
                 de: '.ico Datei',
                 pt_br: 'Arquivo .ico',
@@ -654,6 +686,7 @@ const translationMap = {
                 en: 'DIRECTORY',
                 zh: '目录',
                 zh_tw: '目錄',
+                ua: 'Директорія',
                 ru: 'Директория',
                 de: 'VERZEICHNIS',
                 pt_br: 'DIRETÓRIO',
@@ -674,6 +707,7 @@ const translationMap = {
                 en: 'ARGUMENTS',
                 zh: '参数',
                 zh_tw: '參數',
+                ua: 'Аргументи',
                 ru: 'Аргументы',
                 de: 'ARGUMENTE',
                 pt_br: 'ARGUMENTOS',
@@ -696,7 +730,9 @@ const translationMap = {
                 en: 'The directory to put the output in. Will be created if it doesn\'t exist',
                 zh: '用于放置输出的目录。如果不存在，将创建该目录',
                 zh_tw: '用於放置輸出的目錄如果不存在，將自動創建該目錄',
+                ua: 'Директорія, в яку буде зібрано кінцевий застосунок. Буде створено за необхідності',
                 ru: 'Папка, в которую переместиться итоговое приложение. Будет создано при необходимости.',
+                de: 'Ausgabeverzeichnis. Wird erzeugt wenn es nicht existiert',
                 pt_br: 'O diretório para colocar a saída. Será criado se não existir',
                 sp: 'El directorio para colocar el archivo de salida. Será creado si no existe',
                 sp_la: 'El directorio para colocar el archivo de salida. Será creado si no existe',
@@ -715,7 +751,9 @@ const translationMap = {
                 en: 'Having this enabled will set the recursion limit to 5000 using sys.setrecursionlimit(5000).',
                 zh: '启用此功能将使用sys.setrecursionlimit（5000）将递归限制设置为5000。',
                 zh_tw: '啟用此功能將使用 sys.setrecursionlimit（5000）將遞歸限制設置為5000。',
+                ua: 'Якщо увімкнено, встановить ліміт глибини рекурсії рівний 5000 використовуючи sys.setrecursionlimit(5000).',
                 ru: 'Если включено установит лимит рекурсии равный 5000 с помощью sys.setrecursionlimit(5000).',
+                de: 'Setzt das Rekursionslimit auf 5000 per sys.setrecursionlimit(5000).',
                 pt_br: 'Ativar isso definirá o limite de recursão para 5000 usando sys.setrecursionlimit(5000)',
                 sp: 'Al activar esto se definirá el límite de recursión a 5000 usando sys.setrecursionlimit(5000)',
                 sp_la: 'Al activar esto se definirá el límite de recursión a 5000 usando sys.setrecursionlimit(5000)',
@@ -734,7 +772,9 @@ const translationMap = {
                 en: 'Inject raw text into the generated command.',
                 zh: '将原始文本插入到生成的命令中。',
                 zh_tw: '將原始文字插入到產生的命令中。',
+                ua: 'Додасть текст в кінцеву команду',
                 ru: 'Вставит текст в итоговую команду',
+                de: 'Text zum generierten Befehl hinzufügen.',
                 pt_br: 'Injete texto bruto no comando gerado.',
                 sp: 'Inserte texto bruto en el comando generado',
                 sp_la: 'Inserte texto bruto en el comando generado',
@@ -755,8 +795,9 @@ const translationMap = {
                 en: 'Warning: this file is not a valid .ico file',
                 zh: '警告：此文件不是有效的 .ico 文件',
                 zh_tw: '警告：此文件不是有效的 .ico 文件',
+                ua: 'Попередження: це недопустимий файл .ico',
                 ru: 'Предупреждение: этот файл не является допустимым файлом .ico',
-                de: 'Warnung: Diese Datei ist keine gültige ICO-Datei',
+                de: 'Warnung: Diese Datei ist keine gültige .ico-Datei',
                 pt_br: 'Aviso: este arquivo não é um arquivo .ico válido',
                 sp: 'Advertencia: este archivo no es un archivo .ico válido',
                 sp_la: 'Advertencia: este archivo no es un archivo .ico válido',
@@ -781,9 +822,15 @@ const translationMap = {
                 zh_tw: '使用單檔案模式的附加檔案時要小心;\n' +
                     '<a href="https://stackoverflow.com/a/13790741/" style="text-decoration: none;">read this</a>\n' +
                     '並更新您的代碼以使用 PyInstaller。',
+                ua: 'Будьте уважні під час використання додаткових файлів в режимі onefile;' +
+                    '<a href="https://stackoverflow.com/a/13790741/" style="text-decoration: none;">Прочитайте це</a>\n' +
+                    'і оновіть свій код для подальшого використання PyInstaller.',
                 ru: 'Будьте внимательны при использовании дополнительных файлов в режиме одного файла;\n' +
                     '<a href="https://stackoverflow.com/a/13790741/" style="text-decoration: none;">Прочитайте Это</a>\n' +
                     'и обновите свой код для работы с PyInstaller.',
+                de: 'Vorsicht bei Verwendung von zusätzlichen Dateien im Modus "Eine Datei";\n' +
+                    '<a href="https://stackoverflow.com/a/13790741/" style="text-decoration: none;">Siehe</a>\n' +
+                    'und aktualisiere den Code zur Verwendung mit PyInstaller.',
                 pt_br: 'Tenha cuidado ao usar arquivos adicionais com o modo de arquivo único;\n' +
                     '<a href="https://stackoverflow.com/a/13790741/" style="text-decoration: none;">read this</a>\n' +
                     'and update your code to work with PyInstaller.',
@@ -828,8 +875,10 @@ const translationMap = {
                 en: 'If you want to put files in the root directory, put a period (.) in the destination.',
                 zh: '如果要将文件放到根目录中，请在目标目录中输入句点(.)。',
                 zh_tw: '如果要將檔案放到根目錄中，請在目標目錄中輸入句點(.)。',
+                ua: 'Якщо хочете розмістити файли в основній директорії, додайте крапку (.) на початку шляху.',
                 ru: 'Если вы хотите расположить файлы в главной директории, вставьте точку (.) в начале пути.',
                 pt_br: 'Se você quiser colocar arquivos no diretório raiz, coloque um ponto (.) no destino.',
+                de: 'Um Dateien im Rootverzeichnis zu speichern, verwende einen Punkt (.) bei der Angabe des Zielverzeichnisses.',
                 sp: 'Si quiere poner los archivos en el directorio raíz, ponga un punto (.) en el destino.',
                 sp_la: 'Si quiere poner los archivos en el directorio raíz, ponga un punto (.) en el destino.',
                 tr: 'Dosyaları kök dizine koymak istiyorsanız, hedefe nokta (.) koyun.',
@@ -853,9 +902,14 @@ const translationMap = {
                 zh_tw: '您的 exe 有問題? 請閱讀 ' +
                     `<a href="${helpPostUrl}" target="_blank">這篇文章是關於如何修復常見的問題</a>` +
                     ' 尋找可能的解決方案。',
+                ua: 'Щось не так з вашим EXE? Можете з легкістю знайти відповідь' +
+                    `<a href="${helpPostUrl}" target="_blank">тут, ознайомившись з описом більшості проблем</a>`,
                 ru: 'Что-то не так с вашим exe? Прочитайте ' +
                     `<a href="${helpPostUrl}" target="_blank">эту справку, с описанием большинства проблем</a>` +
                     ' чтобы решить свою.',
+                de: 'Probleme mit der .exe-Datei? Lies ' +
+                    `<a href="${helpPostUrl}" target="_blank">diesen Artikel zur Behebung von bekannten Problemen</a>` +
+                    ' für mögliche Lösungen.',
                 pt_br: 'Algo errado com seu exe? Read ' +
                     `<a href="${helpPostUrl}" target="_blank">este post fala sobre os problemas comuns</a>` +
                     ' e possíveis soluções.',
@@ -905,6 +959,7 @@ const translationMap = {
                 en: 'General Options',
                 zh: '常规选项',
                 zh_tw: '一般選項',
+                ua: 'Основні Налаштування',
                 ru: 'Основные Настройки',
                 de: 'Allgemeine Optionen',
                 pt_br: 'Opções Gerais',
@@ -925,6 +980,7 @@ const translationMap = {
                 en: 'What to bundle, where to search',
                 zh: '捆绑什么，搜索哪里',
                 zh_tw: '怎樣捆綁，哪裡搜尋',
+                ua: 'Що використовується і де це шукати',
                 ru: 'Что используется и где это искать',
                 de: 'Was zusammenfassen, wo suchen',
                 pt_br: 'O que agrupar, onde pesquisar',
@@ -945,8 +1001,9 @@ const translationMap = {
                 en: 'How to generate',
                 zh: '如何生成',
                 zh_tw: '如何產生',
+                ua: 'Налаштування генератора',
                 ru: 'Настройки генератора',
-                de: 'Wie generieren...?',
+                de: 'Wie generieren',
                 pt_br: 'Como gerar',
                 sp: 'Como generar',
                 sp_la: 'Como generar',
@@ -964,8 +1021,9 @@ const translationMap = {
             windowsAndMacOsXSpecificOptions: {
                 en: 'Windows And Mac Os X Specific Options',
                 zh_tw: 'Windows 和 Mac Os X 特定選項',
+                ua: 'Налаштування для Windows та Mac OS X',
                 ru: 'Настройки для Windows и Mac Os X',
-                de: 'Windows und Mac Os X spezifische Optionen',
+                de: 'Windows- und macOS-spezifische Optionen',
                 pt_br: 'Opções específicas Windows e Mac Os X',
                 sp: 'Opciones específicas Windows y Mac Os X',
                 sp_la: 'Opciones específicas de Windows y de Mac Os X',
@@ -984,8 +1042,9 @@ const translationMap = {
                 en: 'Windows specific options',
                 zh: 'Windows特定选项',
                 zh_tw: 'Windows 特定選項',
+                ua: 'Налаштування для Windows',
                 ru: 'Настройки для Windows',
-                de: 'Windows spezifische Optionen',
+                de: 'Windows-spezifische Optionen',
                 pt_br: 'Opções específicas Windows',
                 sp: 'Opciones específicas Windows',
                 sp_la: 'Opciones específicas de Windows',
@@ -1004,6 +1063,7 @@ const translationMap = {
                 en: 'Windows Side-by-side Assembly searching options (advanced)',
                 zh: '窗口并排汇编搜索选项(高级)',
                 zh_tw: '視窗並排彙編搜尋選項(進階)',
+                ua: 'Параметри пошуку паралельних збірок Windows (додатково)',
                 ru: 'Параметры поиска параллельных сборок Windows (дополнительно)',
                 de: 'Windows Side-by-side Suchoptionen (Erweitert)',
                 pt_br: 'Opções de pesquisa dSide-by-side Assembly do Windows (avançado)',
@@ -1024,8 +1084,9 @@ const translationMap = {
                 en: 'Mac OS X specific options',
                 zh: 'Mac OS X特定选项',
                 zh_tw: 'Mac OS X 特定選項',
+                ua: 'Налаштування для Mac OS X',
                 ru: 'Настройки для Mac OS X',
-                de: 'Mac OS X spezifische Optionen',
+                de: 'macOS-spezifische Optionen',
                 pt_br: 'Opções específicas Mac OS X',
                 sp: 'Opciones específicas Mac OS X',
                 sp_la: 'Opciones específicas de Mac OS X',
@@ -1044,8 +1105,9 @@ const translationMap = {
                 en: 'Rarely used special options',
                 zh: '很少使用的特殊选项',
                 zh_tw: '很少使用的特殊選項',
+                ua: 'Додаткові опції, що рідко використовуються',
                 ru: 'Редко используемые дополнительные опции',
-                de: 'Selten genuzte Spezialoptionen',
+                de: 'Selten genutzte Spezialoptionen',
                 pt_br: 'Opções especiais raramente usadas',
                 sp: 'Opciones especiales raramente usadas',
                 sp_la: 'Opciones especiales raramente usadas',
@@ -1064,6 +1126,7 @@ const translationMap = {
                 en: 'Other',
                 zh: '其他',
                 zh_tw: '其它',
+                ua: 'Інше',
                 ru: 'Другое',
                 de: 'Andere',
                 pt_br: 'Outros',
@@ -1087,6 +1150,7 @@ const translationMap = {
                 en: 'Browse for File',
                 zh: '浏览文件',
                 zh_tw: '瀏覽檔案',
+                ua: 'Пошук файлу',
                 ru: 'Поиск файла',
                 de: 'Datei suchen',
                 pt_br: 'Procurar arquivo',
@@ -1107,6 +1171,7 @@ const translationMap = {
                 en: 'Browse for Folder',
                 zh: '浏览文件夹',
                 zh_tw: '瀏覽檔案夾',
+                ua: 'Пошук директорії',
                 ru: 'Поиск Папки',
                 de: 'Verzeichnis suchen',
                 pt_br: 'Procurar Pasta',
@@ -1127,6 +1192,7 @@ const translationMap = {
                 en: 'Enable',
                 zh: '开启',
                 zh_tw: '開啟',
+                ua: 'Увімкнути',
                 ru: 'Включить',
                 de: 'Aktivieren',
                 pt_br: 'Habilitar',
@@ -1147,6 +1213,7 @@ const translationMap = {
                 en: 'Disable',
                 zh: '关掉',
                 zh_tw: '關閉',
+                ua: 'Вимкнути',
                 ru: 'Выключить',
                 de: 'Deaktivieren',
                 pt_br: 'Desabilitar',
@@ -1167,6 +1234,7 @@ const translationMap = {
                 en: 'Converting...',
                 zh: '转换中······',
                 zh_tw: '轉換中······',
+                ua: 'Конвертація...',
                 ru: 'Преобразование...',
                 de: 'Konvertierung...',
                 pt_br: 'Convertendo...',
@@ -1187,6 +1255,7 @@ const translationMap = {
                 en: 'Clear Output',
                 zh: '清除输出f',
                 zh_tw: '清除輸出',
+                ua: 'Очистка Виводу',
                 ru: 'Отчистить Вывод',
                 de: 'Ausgabe löschen',
                 pt_br: 'Limpar Saída',
@@ -1209,6 +1278,7 @@ const translationMap = {
                 en: 'Override current configuration?',
                 zh: '覆盖当前配置？',
                 zh_tw: '覆蓋當前配置？',
+                ua: 'Перезапис активних налаштувань',
                 ru: 'Перезаписать текущие настройки?',
                 de: 'Aktuelle Konfiguration überschreiben?',
                 pt_br: 'Substituir a configuração atual?',
@@ -1229,6 +1299,7 @@ const translationMap = {
                 en: 'All previously inserted values will be erased.',
                 zh: '所有先前插入的值将被删除。',
                 zh_tw: '所有先前插入的值將被刪除。',
+                ua: 'Всі попередні налаштування будуть видалені.',
                 ru: 'Все ранее текущие значения будут удалены.',
                 de: 'Alle zuvor eingegebenen Werte werden gelöscht.',
                 pt_br: 'Todos os valores inseridos anteriormente serão apagados.',
@@ -1249,6 +1320,7 @@ const translationMap = {
                 en: 'Confirm',
                 zh: '确认',
                 zh_tw: '確認',
+                ua: 'Підтвердити',
                 ru: 'Подтвердить',
                 de: 'Bestätigen',
                 pt_br: 'Confirma',
@@ -1269,6 +1341,7 @@ const translationMap = {
                 en: 'Cancel',
                 zh: '取消',
                 zh_tw: '取消',
+                ua: 'Відміна',
                 ru: 'Отмена',
                 de: 'Abbrechen',
                 pt_br: 'Cancela',
@@ -1294,8 +1367,9 @@ const translationMap = {
                 en: 'You have not provided your scripts location.\nPlease enter this at the top of the page.',
                 zh: '您尚未提供脚本位置。\n请在页面顶部输入。',
                 zh_tw: '您尚未提供腳本位置。\n請在頁面頂部輸入。',
+                ua: 'Ви не вказали місцезнаходження скрипта.\nВкажіть його на початку сторінки.',
                 ru: 'Вы не указали расположение скрипта.\nУкажите его в самом верху страницы',
-                de: 'Keinen Pfad zum Skript angegeben.\nBitte den Pfad zum Skript oben in der Seite eingeben.',
+                de: 'Kein Pfad zum Skript angegeben.\nBitte den Pfad zum Skript oben in der Seite eingeben.',
                 pt_br: 'Você não forneceu o local dos seus scripts.\nPor favor, insira-o na parte superior da página.',
                 sp: 'No ha facilitado la ubicación de sus guiones. \nPor favor, introdúzcala en la parte superior de la página.',
                 sp_la: 'No ha facilitado la ubicación de sus guiones. \nPor favor, introdúzcala en la parte superior de la página.',
@@ -1314,8 +1388,9 @@ const translationMap = {
                 en: 'This action will overwrite a previous output in the output folder.\nContinue?',
                 zh: '此操作将覆盖输出文件夹中以前的输出。\n是否继续？',
                 zh_tw: '此操作將覆蓋輸出檔案夾中以前的輸出。\n是否繼續？',
+                ua: 'Ця дія перезапише поперденій вивід у кінцевій директорії.\nПродовжуємо?',
                 ru: 'Это действие перезапишет предыдущий вывод в папке вывода.\nПродолжить?',
-                de: 'Diese Aktion wird vorige Ausgaben im Ausgabeverzeichnis überschreiben.\nWeitermachen?',
+                de: 'Diese Aktion wird vorige Ausgaben im Ausgabeverzeichnis überschreiben.\nFortsetzen?',
                 pt_br: 'Esta ação substituirá uma saída anterior na pasta de saída.\nContinuar?',
                 sp: 'Esta acción sobrescribirá una salida anterior en la carpeta de salida.\n¿Continuar?',
                 sp_la: 'Esta acción sobrescribirá una salida anterior en la carpeta de salida.\n¿Desea continuar?',
@@ -1497,6 +1572,10 @@ const supportedLanguages = [
         name: 'Turkish (Türkçe)',
         code: 'tr',
     },
+    {
+        name: 'Ukrainian (Українська)',
+        code: 'ua',
+    },
 ];
 
 let currentLanguage = _checkLanguageIsSupportedOrDefault(_getLanguage()); // Keeps track of the current language
